@@ -1,41 +1,5 @@
-/***************************************************************************
-**
-** Copyright (C) 2020 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtCore module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #ifndef QPROPERTY_P_H
 #define QPROPERTY_P_H
@@ -51,11 +15,13 @@
 // We mean it.
 //
 
-#include <qglobal.h>
+#include <private/qglobal_p.h>
 #include <qproperty.h>
 
+#include <qmetaobject.h>
 #include <qscopedpointer.h>
 #include <qscopedvaluerollback.h>
+#include <qvariant.h>
 #include <vector>
 #include <QtCore/QVarLengthArray>
 
@@ -79,16 +45,16 @@ private:
     QPropertyObserver *d = nullptr;
 public:
     QBindingObserverPtr() = default;
-    Q_DISABLE_COPY(QBindingObserverPtr);
+    Q_DISABLE_COPY(QBindingObserverPtr)
     void swap(QBindingObserverPtr &other) noexcept
     { qt_ptr_swap(d, other.d); }
-    QBindingObserverPtr(QBindingObserverPtr &&other) : d(std::exchange(other.d, nullptr)) {}
-    QT_MOVE_ASSIGNMENT_OPERATOR_IMPL_VIA_MOVE_AND_SWAP(QBindingObserverPtr);
+    QBindingObserverPtr(QBindingObserverPtr &&other) noexcept : d(std::exchange(other.d, nullptr)) {}
+    QT_MOVE_ASSIGNMENT_OPERATOR_IMPL_VIA_MOVE_AND_SWAP(QBindingObserverPtr)
 
 
-    inline QBindingObserverPtr(QPropertyObserver *observer);
+    inline QBindingObserverPtr(QPropertyObserver *observer) noexcept;
     inline ~QBindingObserverPtr();
-    inline QPropertyBindingPrivate *binding() const;
+    inline QPropertyBindingPrivate *binding() const noexcept;
     inline QPropertyObserver *operator ->();
 };
 
@@ -98,7 +64,7 @@ using PendingBindingObserverList = QVarLengthArray<QBindingObserverPtr>;
 // we need to allow the compiler to inline where it makes sense.
 
 // This is a helper "namespace"
-struct Q_AUTOTEST_EXPORT QPropertyBindingDataPointer
+struct QPropertyBindingDataPointer
 {
     const QtPrivate::QPropertyBindingData *ptr = nullptr;
 
@@ -115,10 +81,11 @@ struct Q_AUTOTEST_EXPORT QPropertyBindingDataPointer
     }
     static void fixupAfterMove(QtPrivate::QPropertyBindingData *ptr);
     void Q_ALWAYS_INLINE addObserver(QPropertyObserver *observer);
-    void setFirstObserver(QPropertyObserver *observer);
-    QPropertyObserverPointer firstObserver() const;
+    inline void setFirstObserver(QPropertyObserver *observer);
+    inline QPropertyObserverPointer firstObserver() const;
+    static QPropertyProxyBindingData *proxyData(QtPrivate::QPropertyBindingData *ptr);
 
-    int observerCount() const;
+    inline int observerCount() const;
 
     template <typename T>
     static QPropertyBindingDataPointer get(QProperty<T> &property)
@@ -127,7 +94,10 @@ struct Q_AUTOTEST_EXPORT QPropertyBindingDataPointer
     }
 };
 
-struct [[nodiscard]] QPropertyObserverNodeProtector {
+struct [[nodiscard]] QPropertyObserverNodeProtector
+{
+    Q_DISABLE_COPY_MOVE(QPropertyObserverNodeProtector)
+
     QPropertyObserverBase m_placeHolder;
     QPropertyObserverNodeProtector(QPropertyObserver *observer)
     {
@@ -151,10 +121,26 @@ struct QPropertyObserverPointer
 {
     QPropertyObserver *ptr = nullptr;
 
-    void unlink();
-    void unlink_fast();
+    void unlink()
+    {
+        unlink_common();
+        if (ptr->next.tag() == QPropertyObserver::ObserverIsAlias)
+            ptr->aliasData = nullptr;
+    }
+
+    void unlink_fast()
+    {
+        Q_ASSERT(ptr->next.tag() != QPropertyObserver::ObserverIsAlias);
+        unlink_common();
+    }
+
+    void setBindingToNotify(QPropertyBindingPrivate *binding)
+    {
+        Q_ASSERT(ptr->next.tag() != QPropertyObserver::ObserverIsPlaceholder);
+        ptr->binding = binding;
+        ptr->next.setTag(QPropertyObserver::ObserverNotifiesBinding);
+    }
 
-    void setBindingToNotify(QPropertyBindingPrivate *binding);
     void setBindingToNotify_unsafe(QPropertyBindingPrivate *binding);
     void setChangeHandler(QPropertyObserver::ChangeHandler changeHandler);
 
@@ -179,7 +165,18 @@ struct QPropertyObserverPointer
     {
         Q_ASSERT(ptr->next.tag() == QPropertyObserver::ObserverNotifiesBinding);
         return ptr->binding;
-    };
+    }
+
+private:
+    void unlink_common()
+    {
+        if (ptr->next)
+            ptr->next->prev = ptr->prev;
+        if (ptr->prev)
+            ptr->prev.setPointer(ptr->next.data());
+        ptr->next = nullptr;
+        ptr->prev.clear();
+    }
 };
 
 class QPropertyBindingErrorPrivate : public QSharedData
@@ -227,6 +224,33 @@ struct CompatPropertySafePoint
     QtPrivate::BindingEvaluationState *bindingState = nullptr;
 };
 
+/*!
+ * \internal
+ * While the regular QProperty notification for a compat property runs we
+ * don't want to have any currentCompatProperty set. This would be a _different_
+ * one than the one we are current evaluating. Therefore it's misleading and
+ * prevents the registering of actual dependencies.
+ */
+struct CurrentCompatPropertyThief
+{
+    Q_DISABLE_COPY_MOVE(CurrentCompatPropertyThief)
+public:
+    CurrentCompatPropertyThief(QBindingStatus *status)
+        : status(&status->currentCompatProperty)
+        , stolen(std::exchange(status->currentCompatProperty, nullptr))
+    {
+    }
+
+    ~CurrentCompatPropertyThief()
+    {
+        *status = stolen;
+    }
+
+private:
+    CompatPropertySafePoint **status = nullptr;
+    CompatPropertySafePoint *stolen = nullptr;
+};
+
 }
 
 class Q_CORE_EXPORT QPropertyBindingPrivate : public QtPrivate::RefCounted
@@ -282,7 +306,7 @@ protected:
         };
     };
 private:
-    QPropertyBindingError error;
+    QPropertyBindingError m_error;
 
     QMetaType metaType;
 
@@ -347,15 +371,7 @@ public:
         return observers;
     }
 
-    void clearDependencyObservers() {
-        for (size_t i = 0; i < qMin(dependencyObserverCount, inlineDependencyObservers.size()); ++i) {
-            QPropertyObserverPointer p{&inlineDependencyObservers[i]};
-            p.unlink_fast();
-        }
-        if (heapObservers)
-            heapObservers->clear();
-        dependencyObserverCount = 0;
-    }
+    void clearDependencyObservers();
 
     Q_ALWAYS_INLINE QPropertyObserverPointer allocateDependencyObserver() {
         if (dependencyObserverCount < inlineDependencyObservers.size()) {
@@ -365,13 +381,7 @@ public:
         return allocateDependencyObserver_slow();
     }
 
-    Q_NEVER_INLINE QPropertyObserverPointer allocateDependencyObserver_slow()
-    {
-        ++dependencyObserverCount;
-        if (!heapObservers)
-            heapObservers.reset(new std::vector<QPropertyObserver>());
-        return {&heapObservers->emplace_back()};
-    }
+    QPropertyObserverPointer allocateDependencyObserver_slow();
 
     QPropertyBindingSourceLocation sourceLocation() const
     {
@@ -382,21 +392,14 @@ public:
         location.fileName = msg;
         return location;
     }
-    QPropertyBindingError bindingError() const { return error; }
+    QPropertyBindingError bindingError() const { return m_error; }
     QMetaType valueMetaType() const { return metaType; }
 
     void unlinkAndDeref();
 
-    void evaluateRecursive(PendingBindingObserverList &bindingObservers, QBindingStatus *status = nullptr);
+    bool evaluateRecursive(PendingBindingObserverList &bindingObservers, QBindingStatus *status = nullptr);
 
-    // ### TODO: remove as soon as declarative no longer needs this overload
-    void evaluateRecursive()
-    {
-        PendingBindingObserverList bindingObservers;
-        evaluateRecursive(bindingObservers);
-    }
-
-    void Q_ALWAYS_INLINE evaluateRecursive_inline(PendingBindingObserverList &bindingObservers, QBindingStatus *status);
+    bool Q_ALWAYS_INLINE evaluateRecursive_inline(PendingBindingObserverList &bindingObservers, QBindingStatus *status);
 
     void notifyRecursive();
     void notifyNonRecursive(const PendingBindingObserverList &bindingObservers);
@@ -407,7 +410,7 @@ public:
     { return static_cast<QPropertyBindingPrivate *>(binding.d.data()); }
 
     void setError(QPropertyBindingError &&e)
-    { error = std::move(e); }
+    { m_error = std::move(e); }
 
     void detachFromProperty()
     {
@@ -450,9 +453,9 @@ inline void QPropertyBindingDataPointer::fixupAfterMove(QtPrivate::QPropertyBind
 {
     auto &d = ptr->d_ref();
     if (ptr->isNotificationDelayed()) {
-        QPropertyProxyBindingData *proxyData
-                = reinterpret_cast<QPropertyProxyBindingData*>(d & ~QtPrivate::QPropertyBindingData::BindingBit);
-        proxyData->originalBindingData = ptr;
+        QPropertyProxyBindingData *proxy = ptr->proxyData();
+        Q_ASSERT(proxy);
+        proxy->originalBindingData = ptr;
     }
     // If QPropertyBindingData has been moved, and it has an observer
     // we have to adjust the firstObserver's prev pointer to point to
@@ -470,18 +473,38 @@ inline QPropertyObserverPointer QPropertyBindingDataPointer::firstObserver() con
     return { reinterpret_cast<QPropertyObserver *>(ptr->d()) };
 }
 
+/*!
+    \internal
+    Returns the proxy data of \a ptr, or \c nullptr if \a ptr has no delayed notification
+ */
+inline QPropertyProxyBindingData *QPropertyBindingDataPointer::proxyData(QtPrivate::QPropertyBindingData *ptr)
+{
+    if (!ptr->isNotificationDelayed())
+        return nullptr;
+    return ptr->proxyData();
+}
+
+inline int QPropertyBindingDataPointer::observerCount() const
+{
+    int count = 0;
+    for (auto observer = firstObserver(); observer; observer = observer.nextObserver())
+        ++count;
+    return count;
+}
+
 namespace QtPrivate {
     Q_CORE_EXPORT bool isPropertyInBindingWrapper(const QUntypedPropertyData *property);
     void Q_CORE_EXPORT initBindingStatusThreadId();
 }
 
-template<typename Class, typename T, auto Offset, auto Setter, auto Signal=nullptr>
+template<typename Class, typename T, auto Offset, auto Setter, auto Signal = nullptr,
+         auto Getter = nullptr>
 class QObjectCompatProperty : public QPropertyData<T>
 {
     template<typename Property, typename>
     friend class QtPrivate::QBindableInterfaceForProperty;
 
-    using ThisType = QObjectCompatProperty<Class, T, Offset, Setter, Signal>;
+    using ThisType = QObjectCompatProperty<Class, T, Offset, Setter, Signal, Getter>;
     using SignalTakesValue = std::is_invocable<decltype(Signal), Class, T>;
     Class *owner()
     {
@@ -497,13 +520,16 @@ class QObjectCompatProperty : public QPropertyData<T>
     static bool bindingWrapper(QMetaType type, QUntypedPropertyData *dataPtr, QtPrivate::QPropertyBindingFunction binding)
     {
         auto *thisData = static_cast<ThisType *>(dataPtr);
-        QPropertyData<T> copy;
-        binding.vtable->call(type, &copy, binding.functor);
-        if constexpr (QTypeTraits::has_operator_equal_v<T>)
-            if (copy.valueBypassingBindings() == thisData->valueBypassingBindings())
-                return false;
-        // ensure value and setValue know we're currently evaluating our binding
         QBindingStorage *storage = qGetBindingStorage(thisData->owner());
+        QPropertyData<T> copy;
+        {
+            QtPrivate::CurrentCompatPropertyThief thief(storage->bindingStatus);
+            binding.vtable->call(type, &copy, binding.functor);
+            if constexpr (QTypeTraits::has_operator_equal_v<T>)
+                if (copy.valueBypassingBindings() == thisData->valueBypassingBindings())
+                    return false;
+        }
+        // ensure value and setValue know we're currently evaluating our binding
         QtPrivate::CompatPropertySafePoint guardThis(storage->bindingStatus, thisData);
         (thisData->owner()->*Setter)(copy.valueBypassingBindings());
         return true;
@@ -514,6 +540,14 @@ class QObjectCompatProperty : public QPropertyData<T>
             && QtPrivate::isPropertyInBindingWrapper(this);
     }
 
+    inline static T getPropertyValue(const QUntypedPropertyData *d) {
+        auto prop = static_cast<const ThisType *>(d);
+        if constexpr (std::is_null_pointer_v<decltype(Getter)>)
+            return prop->value();
+        else
+            return (prop->owner()->*Getter)();
+    }
+
 public:
     using value_type = typename QPropertyData<T>::value_type;
     using parameter_type = typename QPropertyData<T>::parameter_type;
@@ -587,7 +621,7 @@ public:
         return true;
     }
 
-#ifndef Q_CLANG_QDOC
+#ifndef Q_QDOC
     template <typename Functor>
     QPropertyBinding<T> setBinding(Functor &&f,
                                    const QPropertyBindingSourceLocation &location = QT_PROPERTY_DEFAULT_BINDING_LOCATION,
@@ -619,12 +653,29 @@ public:
     {
         QBindingStorage *storage = qGetBindingStorage(owner());
         if (auto bd = storage->bindingData(this, false)) {
-            if (!inBindingWrapper(storage))
-                notify(bd);
+            // This partly duplicates QPropertyBindingData::notifyObservers because we want to
+            // check for inBindingWrapper() after checking for isNotificationDelayed() and
+            // firstObserver. This is because inBindingWrapper() is the most expensive check.
+            if (!bd->isNotificationDelayed()) {
+                QPropertyBindingDataPointer d{bd};
+                if (QPropertyObserverPointer observer = d.firstObserver()) {
+                    if (!inBindingWrapper(storage)) {
+                        PendingBindingObserverList bindingObservers;
+                        if (bd->notifyObserver_helper(this, storage, observer, bindingObservers)
+                                == QtPrivate::QPropertyBindingData::Evaluated) {
+                            // evaluateBindings() can trash the observers. We need to re-fetch here.
+                            if (QPropertyObserverPointer observer = d.firstObserver())
+                                observer.notifyOnlyChangeHandler(this);
+                            for (auto&& bindingObserver: bindingObservers)
+                                bindingObserver.binding()->notifyNonRecursive();
+                        }
+                    }
+                }
+            }
         }
         if constexpr (!std::is_null_pointer_v<decltype(Signal)>) {
             if constexpr (SignalTakesValue::value)
-                (owner()->*Signal)(value());
+                (owner()->*Signal)(getPropertyValue(this));
             else
                 (owner()->*Signal)();
         }
@@ -668,25 +719,19 @@ public:
         auto *storage = const_cast<QBindingStorage *>(qGetBindingStorage(owner()));
         return *storage->bindingData(const_cast<QObjectCompatProperty *>(this), true);
     }
-
-private:
-    void notify(const QtPrivate::QPropertyBindingData *binding)
-    {
-        if (binding)
-            binding->notifyObservers(this, qGetBindingStorage(owner()));
-    }
 };
 
 namespace QtPrivate {
-template<typename Class, typename Ty, auto Offset, auto Setter, auto Signal>
-class QBindableInterfaceForProperty<QObjectCompatProperty<Class, Ty, Offset, Setter, Signal>, std::void_t<Class>>
+template<typename Class, typename Ty, auto Offset, auto Setter, auto Signal, auto Getter>
+class QBindableInterfaceForProperty<
+        QObjectCompatProperty<Class, Ty, Offset, Setter, Signal, Getter>, std::void_t<Class>>
 {
-    using Property = QObjectCompatProperty<Class, Ty, Offset, Setter, Signal>;
+    using Property = QObjectCompatProperty<Class, Ty, Offset, Setter, Signal, Getter>;
     using T = typename Property::value_type;
 public:
     static constexpr QBindableInterface iface = {
         [](const QUntypedPropertyData *d, void *value) -> void
-        { *static_cast<T*>(value) = static_cast<const Property *>(d)->value(); },
+        { *static_cast<T*>(value) = Property::getPropertyValue(d); },
         [](QUntypedPropertyData *d, const void *value) -> void
         {
             (static_cast<Property *>(d)->owner()->*Setter)(*static_cast<const T*>(value));
@@ -696,7 +741,7 @@ public:
         [](QUntypedPropertyData *d, const QUntypedPropertyBinding &binding) -> QUntypedPropertyBinding
         { return static_cast<Property *>(d)->setBinding(static_cast<const QPropertyBinding<T> &>(binding)); },
         [](const QUntypedPropertyData *d, const QPropertyBindingSourceLocation &location) -> QUntypedPropertyBinding
-        { return Qt::makePropertyBinding([d]() -> T { return static_cast<const Property *>(d)->value(); }, location); },
+        { return Qt::makePropertyBinding([d]() -> T { return Property::getPropertyValue(d); }, location); },
         [](const QUntypedPropertyData *d, QPropertyObserver *observer) -> void
         { observer->setSource(static_cast<const Property *>(d)->bindingData()); },
         []() { return QMetaType::fromType<T>(); }
@@ -745,6 +790,16 @@ public:
             QObjectCompatProperty<Class, Type, Class::_qt_property_##name##_offset, setter,        \
                                   signal>(value);
 
+#define QT_OBJECT_COMPAT_PROPERTY_WITH_ARGS_7(Class, Type, name, setter, signal, getter, value) \
+    static constexpr size_t _qt_property_##name##_offset() { \
+        QT_WARNING_PUSH QT_WARNING_DISABLE_INVALID_OFFSETOF \
+        return offsetof(Class, name); \
+        QT_WARNING_POP \
+    } \
+    QObjectCompatProperty<Class, Type, Class::_qt_property_##name##_offset, setter, signal, getter>\
+        name = QObjectCompatProperty<Class, Type, Class::_qt_property_##name##_offset, setter,     \
+                                     signal, getter>(value);
+
 #define Q_OBJECT_COMPAT_PROPERTY_WITH_ARGS(...) \
     QT_WARNING_PUSH QT_WARNING_DISABLE_INVALID_OFFSETOF \
     QT_OVERLOADED_MACRO(QT_OBJECT_COMPAT_PROPERTY_WITH_ARGS, __VA_ARGS__) \
@@ -769,13 +824,13 @@ struct QUntypedBindablePrivate
     }
 };
 
-inline void QPropertyBindingPrivate::evaluateRecursive_inline(PendingBindingObserverList &bindingObservers, QBindingStatus *status)
+inline bool QPropertyBindingPrivate::evaluateRecursive_inline(PendingBindingObserverList &bindingObservers, QBindingStatus *status)
 {
     if (updating) {
-        error = QPropertyBindingError(QPropertyBindingError::BindingLoop);
+        m_error = QPropertyBindingError(QPropertyBindingError::BindingLoop);
         if (isQQmlPropertyBinding)
             errorCallBack(this);
-        return;
+        return false;
     }
 
     /*
@@ -805,14 +860,15 @@ inline void QPropertyBindingPrivate::evaluateRecursive_inline(PendingBindingObse
     // If there was not, we must not clear it, as that only should happen in notifyRecursive
     pendingNotify = pendingNotify || changed;
     if (!changed || !firstObserver)
-        return;
+        return changed;
 
     firstObserver.noSelfDependencies(this);
     firstObserver.evaluateBindings(bindingObservers, status);
+    return true;
 }
 
 template<QPropertyObserverPointer::Notify notifyPolicy>
-void QPropertyObserverPointer::notify(QUntypedPropertyData *propertyDataPtr)
+inline void QPropertyObserverPointer::notify(QUntypedPropertyData *propertyDataPtr)
 {
     auto observer = const_cast<QPropertyObserver*>(ptr);
     /*
@@ -881,15 +937,57 @@ inline QPropertyObserverNodeProtector::~QPropertyObserverNodeProtector()
     d.unlink_fast();
 }
 
-QBindingObserverPtr::QBindingObserverPtr(QPropertyObserver *observer) : d(observer)
+QBindingObserverPtr::QBindingObserverPtr(QPropertyObserver *observer) noexcept : d(observer)
 {
     Q_ASSERT(d);
     QPropertyObserverPointer{d}.binding()->addRef();
 }
-QBindingObserverPtr::~QBindingObserverPtr() { if (d)  QPropertyObserverPointer{d}.binding()->deref(); }
-QPropertyBindingPrivate *QBindingObserverPtr::binding() const { return QPropertyObserverPointer{d}.binding(); }
+
+QBindingObserverPtr::~QBindingObserverPtr()
+{
+    if (!d)
+        return;
+
+    QPropertyBindingPrivate *bindingPrivate = binding();
+    if (!bindingPrivate->deref())
+        QPropertyBindingPrivate::destroyAndFreeMemory(bindingPrivate);
+}
+
+QPropertyBindingPrivate *QBindingObserverPtr::binding() const noexcept { return QPropertyObserverPointer{d}.binding(); }
+
 QPropertyObserver *QBindingObserverPtr::operator->() { return d; }
 
+namespace QtPrivate {
+class QPropertyAdaptorSlotObject : public QUntypedPropertyData, public QSlotObjectBase
+{
+    QPropertyBindingData bindingData_;
+    QObject *obj;
+    QMetaProperty metaProperty_;
+
+    static void impl(int which, QSlotObjectBase *this_, QObject *r, void **a, bool *ret);
+
+    QPropertyAdaptorSlotObject(QObject *o, const QMetaProperty& p);
+
+public:
+    static QPropertyAdaptorSlotObject *cast(QSlotObjectBase *ptr, int propertyIndex)
+    {
+        if (ptr->isImpl(&QPropertyAdaptorSlotObject::impl)) {
+            auto p = static_cast<QPropertyAdaptorSlotObject *>(ptr);
+            if (p->metaProperty_.propertyIndex() == propertyIndex)
+                return p;
+        }
+        return nullptr;
+    }
+
+    inline const QPropertyBindingData &bindingData() const { return bindingData_; }
+    inline QPropertyBindingData &bindingData() { return bindingData_; }
+    inline QObject *object() const { return obj; }
+    inline const QMetaProperty &metaProperty() const { return metaProperty_; }
+
+    friend class QT_PREPEND_NAMESPACE(QUntypedBindable);
+};
+}
+
 QT_END_NAMESPACE
 
 #endif // QPROPERTY_P_H
