@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the plugins of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qglobal.h"
 
@@ -49,6 +13,7 @@
 #endif
 
 #include <QtCore/qelapsedtimer.h>
+#include <QtCore/private/qcore_mac_p.h>
 
 #include "qcoretextfontdatabase_p.h"
 #include "qfontengine_coretext_p.h"
@@ -64,6 +29,11 @@
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
+QT_IMPL_METATYPE_EXTERN_TAGGED(QCFType<CGFontRef>, QCFType_CGFontRef)
+QT_IMPL_METATYPE_EXTERN_TAGGED(QCFType<CFURLRef>, QCFType_CFURLRef)
+
 // this could become a list of all languages used for each writing
 // system, instead of using the single most common language.
 static const char languageForWritingSystem[][8] = {
@@ -107,6 +77,12 @@ enum { LanguageCount = sizeof languageForWritingSystem / sizeof *languageForWrit
 QCoreTextFontDatabase::QCoreTextFontDatabase()
     : m_hasPopulatedAliases(false)
 {
+#if defined(Q_OS_MACOS)
+    m_fontSetObserver = QMacNotificationObserver(nil, NSFontSetChangedNotification, [] {
+        qCDebug(lcQpaFonts) << "Fonts have changed";
+        QPlatformFontDatabase::repopulateFontDatabase();
+    });
+#endif
 }
 
 QCoreTextFontDatabase::~QCoreTextFontDatabase()
@@ -339,7 +315,7 @@ void QCoreTextFontDatabase::invalidate()
 
     qDeleteAll(m_themeFonts);
     m_themeFonts.clear();
-    QWindowSystemInterface::handleThemeChange<QWindowSystemInterface::SynchronousDelivery>(nullptr);
+    QWindowSystemInterface::handleThemeChange<QWindowSystemInterface::SynchronousDelivery>();
 }
 
 struct FontDescription {
@@ -631,7 +607,7 @@ QStringList QCoreTextFontDatabase::fallbacksForFamily(const QString &family, QFo
     Q_UNUSED(style);
 
     qCDebug(lcQpaFonts).nospace() << "Resolving fallbacks families for"
-        << (!family.isEmpty() ? qPrintable(QLatin1String(" family '%1' with").arg(family)) : "")
+        << (!family.isEmpty() ? qPrintable(" family '%1' with"_L1.arg(family)) : "")
         << " style hint " << styleHint;
 
     QMacAutoReleasePool pool;
@@ -680,7 +656,7 @@ QStringList QCoreTextFontDatabase::fallbacksForFamily(const QString &family, QFo
     // of the required glyphs, or representing them by question marks.
     // Move these to the end, so that the proper fonts are preferred.
     for (const char *family : { ".Apple Symbols Fallback", ".Noto Sans Universal" }) {
-        int index = fallbackList.indexOf(QLatin1String(family));
+        int index = fallbackList.indexOf(QLatin1StringView(family));
         if (index >= 0)
             fallbackList.move(index, fallbackList.size() - 1);
     }
@@ -772,7 +748,7 @@ QStringList QCoreTextFontDatabase::addApplicationFont(const QByteArray &fontData
 
 bool QCoreTextFontDatabase::isPrivateFontFamily(const QString &family) const
 {
-    if (family.startsWith(QLatin1Char('.')) || family == QLatin1String("LastResort") || m_privateFamilies.contains(family))
+    if (family.startsWith(u'.') || family == "LastResort"_L1 || m_privateFamilies.contains(family))
         return true;
 
     return QPlatformFontDatabase::isPrivateFontFamily(family);
@@ -929,7 +905,7 @@ void QCoreTextFontDatabase::populateThemeFonts()
 
             auto addFontVariants = [&](CTFontDescriptorRef descriptor) {
                 QCFType<CFArrayRef> matchingDescriptors = CTFontDescriptorCreateMatchingFontDescriptors(descriptor, nullptr);
-                const int matchingDescriptorsCount = CFArrayGetCount(matchingDescriptors);
+                const int matchingDescriptorsCount = matchingDescriptors ? CFArrayGetCount(matchingDescriptors) : 0;
                 qCDebug(lcQpaFonts) << "Enumerating font variants based on" << id(descriptor)
                     << "resulted in" << matchingDescriptorsCount << "matching descriptors"
                     << matchingDescriptors.as<NSArray*>();
