@@ -563,19 +563,11 @@ static bool addFontToDatabase(QString familyName,
             writingSystems.setSupported(ws);
     }
 
-    // We came here from populating a different font family, so we have
-    // to ensure the entire typographic family is populated before we
-    // mark it as such inside registerFont()
-    if (!subFamilyName.isEmpty()
-            && familyName != subFamilyName
-            && sfp->populatedFontFamily != familyName
-            && !QPlatformFontDatabase::isFamilyPopulated(familyName)) {
-        sfp->windowsFontDatabase->populateFamily(familyName);
-    }
-
+    const bool wasPopulated = QPlatformFontDatabase::isFamilyPopulated(familyName);
     QPlatformFontDatabase::registerFont(familyName, styleName, foundryName, weight,
                                         style, stretch, antialias, scalable, size, fixed, writingSystems, createFontFile(faceName));
 
+
     // add fonts windows can generate for us:
     if (weight <= QFont::DemiBold && styleName.isEmpty())
         QPlatformFontDatabase::registerFont(familyName, QString(), foundryName, QFont::Bold,
@@ -587,6 +579,16 @@ static bool addFontToDatabase(QString familyName,
         QPlatformFontDatabase::registerFont(familyName, QString(), foundryName, QFont::Bold,
                                             QFont::StyleItalic, stretch, antialias, scalable, size, fixed, writingSystems, createFontFile(faceName));
 
+    // We came here from populating a different font family, so we have
+    // to ensure the entire typographic family is populated before we
+    // mark it as such inside registerFont()
+    if (!subFamilyName.isEmpty()
+            && familyName != subFamilyName
+            && sfp->populatedFontFamily != familyName
+            && !wasPopulated) {
+        sfp->windowsFontDatabase->populateFamily(familyName);
+    }
+
     if (!subFamilyName.isEmpty() && familyName != subFamilyName) {
         QPlatformFontDatabase::registerFont(subFamilyName, subFamilyStyle, foundryName, weight,
                                             style, stretch, antialias, scalable, size, fixed, writingSystems, createFontFile(faceName));
@@ -1230,6 +1232,7 @@ QFontEngine *QWindowsFontDatabase::createEngine(const QFontDef &request, const Q
             HRESULT hr = data->directWriteGdiInterop->CreateFontFaceFromHdc(data->hdc, &directWriteFontFace);
             if (SUCCEEDED(hr)) {
                 bool isColorFont = false;
+                bool needsSimulation = false;
 #if QT_CONFIG(direct2d)
                 IDWriteFontFace2 *directWriteFontFace2 = nullptr;
                 if (SUCCEEDED(directWriteFontFace->QueryInterface(__uuidof(IDWriteFontFace2),
@@ -1237,10 +1240,12 @@ QFontEngine *QWindowsFontDatabase::createEngine(const QFontDef &request, const Q
                     if (directWriteFontFace2->IsColorFont())
                         isColorFont = directWriteFontFace2->GetPaletteEntryCount() > 0;
 
+                    needsSimulation = directWriteFontFace2->GetSimulations() != DWRITE_FONT_SIMULATIONS_NONE;
+
                     directWriteFontFace2->Release();
                 }
 #endif // direct2d
-                useDw = useDw || useDirectWrite(hintingPreference, fam, isColorFont);
+                useDw = useDw || useDirectWrite(hintingPreference, fam, isColorFont) || needsSimulation;
                 qCDebug(lcQpaFonts)
                         << __FUNCTION__ << request.families.first() << request.pointSize << "pt"
                         << "hintingPreference=" << hintingPreference << "color=" << isColorFont
